@@ -134,8 +134,8 @@ except:
     pass
 
 def bootstrap(agent=None):
-    print("AGENT BOOTSTRAP")
-    entry_point_refresh()
+    #print("AGENT BOOTSTRAP")
+    #entry_point_refresh()
     import pythonagent.agent.internal.intercept_module
     reload(pythonagent.agent.internal.intercept_module)
     from pythonagent.agent.internal.intercept_module import BT
