@@ -40,7 +40,6 @@ class UDPConnection(object):
 
             self.UDPClientSocket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
             logger.debug("Server Port {}".format(self.server_address_port))
-            print("Server Port", self.server_address_port)
 
             havoc_thread = threading.Thread(target=incoming_message_processor, name="havoc_thread",
                                             args=(self.UDPClientSocket,), daemon=True)
@@ -51,6 +50,7 @@ class UDPConnection(object):
                                                 daemon=True)
             heartbeat_thread.start()
 
+
         except:
             logger.warning("Unable to create UDP Connection")
 
@@ -58,7 +58,6 @@ class UDPConnection(object):
 
         # Send to server using created UDP socket
         try:
-            print("Server Port", self.server_address_port)
             self.UDPClientSocket.sendto(message, self.server_address_port)
 
         except:
@@ -66,17 +65,19 @@ class UDPConnection(object):
 
 
 def heartbeat_sender(udp_socket, address_port, ag_obj):
-    logger.debug("heartbeat sender started")
+    logger.info("heartbeat sender started")
     context = ag_obj.get_transaction_context()
     message = create_heartbeat_message(context)
-    logger.debug("heartbeat message {}".format(message))
-
+    logger.info("heartbeat message {}".format(message))
     while True:
-        udp_socket.sendto(message, address_port)
-        time.sleep(60)
-        logger.debug("heartbeat sent")
-
-
+        try:
+            logger.debug("heartbeat about to send")
+            udp_socket.sendto(message, address_port)
+            logger.info("heartbeat sent")
+            time.sleep(10)
+            logger.debug("heartbeat sleep completed")
+        except Exception as e:
+            logger.error("heartbeat exception", e)
 
 
 def incoming_message_processor(udp_socket):
@@ -87,18 +88,18 @@ def incoming_message_processor(udp_socket):
     # logger.debug("udp.py havoc id {}".format(id(havoc_monitor)))
     udp_socket.settimeout(2.0)
     buffer_size = 4096
-    counter=0
+    counter = 0
 
     while True:
 
         try:  # timeout (non-blocking behaviour) added because in warm-start, listener is not working sometimes
-            counter+=1
-            print("\n\n\n Going to call recv from api for {} time \n\n\n".format(counter))
+            counter += 1
+            logger.debug("counter: {}".format(counter))
+            logger.debug("Going to call recv from api for {} time".format(counter))
             logger.debug("Going to call recv from api")
             data, address = udp_socket.recvfrom(buffer_size)
             logger.debug("incoming received message = {} from address {}".format(data, address))
-            print("\n\n\n incoming received message ={} from adress {} \n\n\n".format(data,address))
-            print("after gettting message")
+            logger.debug("after gettting message")
 
             output = str(data)
 
@@ -135,11 +136,11 @@ def incoming_message_processor(udp_socket):
 
             except Exception as e:
                 logger.warning("Unable to parse config: {}", e)
-                print("unable to parse message except")
+                logger.warning("unable to parse message except")
 
         except socket.timeout:
             logger.debug("recv timed out")  # This is not an exception, but a mechanism to implement timeout
-            print("TIMED OUT AFTER recvfrom")
+            logger.warning("timed out after recvfrom")
 
 
 def generate_bt():
@@ -148,20 +149,15 @@ def generate_bt():
     return id_int
 
 
-
 def sdk_init(agent_obj):
-    #agent_obj.udp_connection = UDPConnection()
-
     agent_obj.udp_connection = UDPConnection(agent_obj)
-
-
-    print("\n\n\n\nCALLED SDK INIT\n\n\n\n")
+    logger.debug("called sdk init")
     context = agent_obj.get_transaction_context()
     logger.debug("transaction context dictionary inside sdk init in udp.py {}".format(context.function_name))
     message = create_init_message(context)
     logger.debug("first message to be sent to proxy {}".format(message))
     agent_obj.udp_connection.send(message)
-    print("\n\n\nINIT SENT \n\n\n")
+    logger.debug("init sent")
     return udp_connection
 
 
