@@ -4,7 +4,9 @@ import time
 import logging
 from pythonagent.agent.internal import udp
 from pythonagent.agent.probes.havoc.havoc_constants import HAVOC_TYPES, EXPIRE_DURATION_MS, SIZE_OF_OBJECTS_BYTES, HAVOC_PROFILES_JSON
-from pythonagent.agent.probes.havoc.custom_memory_stress import apply_memory_leak
+#from pythonagent.agent.probes.havoc.custom_memory_stress import apply_memory_leak
+from pythonagent.utils import get_current_timestamp_in_ms
+
 havoc_types = {
     1: "InBoundService_Delay",
     2: "InBoundService_Failure",
@@ -42,7 +44,8 @@ class NDNetHavocRequest(object):
         if hasattr(havoc_conf, 'hostname'):
             self.hostname = havoc_conf.hostname
 
-        self.startTime = time.time_ns() // 1000000
+        #self.startTime = time.time_ns() // 1000000
+        self.startTime = get_current_timestamp_in_ms()
         self.header_dict = header_dict
         self.nhmid = header_dict["NHMID"]
 
@@ -476,7 +479,8 @@ class NDNetHavocMonitor(object):
 
     def refresh_configs(self, agent_obj):
         self.logger.info("Refreshing Configs")
-        current_time_ms = time.time_ns() // 1000000
+        #current_time_ms = time.time_ns() // 1000000
+        current_time_ms = get_current_timestamp_in_ms()
 
         for havoc_type in HAVOC_TYPES:
             self.logger.info("Checking havoc type: {}".format(havoc_type))
